Fri Sep 15 21:34:28 1995 Roland McGrath <roland@churchy.gnu.ai.mit.edu>
authorRoland McGrath <roland@gnu.org>
Sun, 17 Sep 1995 19:29:59 +0000 (19:29 +0000)
committerRoland McGrath <roland@gnu.org>
Sun, 17 Sep 1995 19:29:59 +0000 (19:29 +0000)
* hurd/hurdsig.c: Include <hurd/crash.h> in place of <hurd/core.h>.
(write_corefile): Call __crash_dump_task instead of __core_dump_task.
Use envariable CRASHSERVER instead of CORESERVER.
* hurd/Makefile (user-interfaces): Replace hurd/core with hurd/crash.

ChangeLog
elf/elf.h
hurd/Makefile
hurd/hurdsig.c

index adc6644..0eadbc0 100644 (file)
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,10 @@
+Fri Sep 15 21:34:28 1995  Roland McGrath  <roland@churchy.gnu.ai.mit.edu>
+
+       * hurd/hurdsig.c: Include <hurd/crash.h> in place of <hurd/core.h>.
+       (write_corefile): Call __crash_dump_task instead of __core_dump_task.
+       Use envariable CRASHSERVER instead of CORESERVER.
+       * hurd/Makefile (user-interfaces): Replace hurd/core with hurd/crash.
+
 Tue Sep 12 14:30:07 1995  Roland McGrath  <roland@churchy.gnu.ai.mit.edu>
 
        * misc/mntent.c: New file.
index 4730b8e..a9b9336 100644 (file)
--- a/elf/elf.h
+++ b/elf/elf.h
@@ -112,7 +112,7 @@ typedef struct
 #define EM_486         6               /* Intel 80486 */
 #define EM_860         7               /* Intel 80860 */
 #define EM_MIPS                8               /* MIPS R3000 big-endian */
-#define EM_S370                9               /* Amdhal */
+#define EM_S370                9               /* Amdahl */
 #define EM_MIPS_RS4_BE 10              /* MIPS R4000 big-endian */
 
 #define EM_SPARC64     11              /* SPARC v9 (not official) 64-bit */
index 805f55b..582f37b 100644 (file)
@@ -35,7 +35,7 @@ interface-library := libhurduser
 user-interfaces                := $(addprefix hurd/,\
                                       auth process startup \
                                       msg msg_reply msg_request \
-                                      exec core interrupt \
+                                      exec crash interrupt \
                                       fs fsys io term socket ifsock)
 server-interfaces      := hurd/msg
 
index ca4e229..7affb90 100644 (file)
@@ -112,7 +112,7 @@ _hurd_thread_sigstate (thread_t thread)
 /* Signal delivery itself is on this page.  */
 
 #include <hurd/fd.h>
-#include <hurd/core.h>
+#include <hurd/crash.h>
 #include <hurd/paths.h>
 #include <setjmp.h>
 #include <fcntl.h>
@@ -125,7 +125,7 @@ _hurd_thread_sigstate (thread_t thread)
 
 int _hurd_core_limit;  /* XXX */
 
/* Call the core server to mummify us before we die.
    Returns nonzero if a core file was written.  */
 static int
 write_corefile (int signo, long int sigcode, int sigerror)
@@ -142,11 +142,11 @@ write_corefile (int signo, long int sigcode, int sigerror)
 
   /* First get a port to the core dumping server.  */
   coreserver = MACH_PORT_NULL;
-  name = _hurdsig_getenv ("CORESERVER");
+  name = _hurdsig_getenv ("CRASHSERVER");
   if (name != NULL)
     coreserver = __file_name_lookup (name, 0, 0);
   if (coreserver == MACH_PORT_NULL)
-    coreserver = __file_name_lookup (_SERVERS_CORE, 0, 0);
+    coreserver = __file_name_lookup (_SERVERS_CRASH, 0, 0);
   if (coreserver == MACH_PORT_NULL)
     return 0;
 
@@ -164,10 +164,10 @@ write_corefile (int signo, long int sigcode, int sigerror)
     return 0;
 
   /* Call the core dumping server to write the core file.  */
-  err = __core_dump_task (coreserver,
-                         __mach_task_self (),
-                         file, _hurdsig_getenv ("GNUTARGET"),
-                         signo, sigcode, sigerror);
+  err = __crash_dump_task (coreserver,
+                          __mach_task_self (),
+                          file, _hurdsig_getenv ("GNUTARGET"),
+                          signo, sigcode, sigerror);
   __mach_port_deallocate (__mach_task_self (), coreserver);
   if (! err)
     /* The core dump into FILE succeeded, so now link it into the
@@ -125,7 +125,7 @@ _hurd_thread_sigstate (thread_t thread)
 int _hurd_core_limit;  /* XXX */
 
-/* Call the core server to mummify us before we die.
+/* Call the crash dump server to mummify us before we die.
    Returns nonzero if a core file was written.  */
 static int